aboutsummaryrefslogtreecommitdiffstats
path: root/apps/app_mixmonitor.c
diff options
context:
space:
mode:
authorkpfleming <kpfleming@f38db490-d61c-443f-a65b-d21fe96a405b>2006-01-03 17:25:39 +0000
committerkpfleming <kpfleming@f38db490-d61c-443f-a65b-d21fe96a405b>2006-01-03 17:25:39 +0000
commit66b30d5d48c1f55b52e24a1c4c50a00dfbfc70f8 (patch)
tree6f75f0731b334b7d0960a3c8d4975a97421bf178 /apps/app_mixmonitor.c
parent852c5ac7f590c59c1b73680aa78a44231264b8ab (diff)
Merged revisions 7740 via svnmerge from
https://origsvn.digium.com/svn/asterisk/branches/1.2 ........ r7740 | kpfleming | 2006-01-03 11:24:56 -0600 (Tue, 03 Jan 2006) | 4 lines revert incorrect fix for bug #6048 from revision 7709 put in correct (simpler) fix add doxygen docs for channel spy 'state' values ........ git-svn-id: http://svn.digium.com/svn/asterisk/trunk@7741 f38db490-d61c-443f-a65b-d21fe96a405b
Diffstat (limited to 'apps/app_mixmonitor.c')
-rw-r--r--apps/app_mixmonitor.c32
1 files changed, 7 insertions, 25 deletions
diff --git a/apps/app_mixmonitor.c b/apps/app_mixmonitor.c
index 743e699ca..dd29dd2f3 100644
--- a/apps/app_mixmonitor.c
+++ b/apps/app_mixmonitor.c
@@ -86,7 +86,6 @@ LOCAL_USER_DECL;
static const char *mixmonitor_spy_type = "MixMonitor";
struct mixmonitor {
- AST_LIST_ENTRY(mixmonitor) list;
struct ast_channel *chan;
char *filename;
char *post_process;
@@ -95,15 +94,12 @@ struct mixmonitor {
int writevol;
};
-AST_LIST_HEAD_STATIC(monitors, mixmonitor);
-
enum {
MUXFLAG_APPEND = (1 << 1),
MUXFLAG_BRIDGED = (1 << 2),
MUXFLAG_VOLUME = (1 << 3),
MUXFLAG_READVOLUME = (1 << 4),
MUXFLAG_WRITEVOLUME = (1 << 5),
- FLAG_STOP = (1 << 6),
} mixmonitor_flags;
enum {
@@ -123,9 +119,9 @@ AST_APP_OPTIONS(mixmonitor_opts, {
static void stopmon(struct ast_channel *chan, struct ast_channel_spy *spy)
{
/* If our status has changed, then the channel we're spying on is gone....
DON'T TOUCH IT!!! RUN AWAY!!! */
- if (spy->status != CHANSPY_RUNNING)
+ if (spy->status == CHANSPY_DONE)
return;
if (!chan)
@@ -168,10 +164,6 @@ static void *mixmonitor_thread(void *obj)
STANDARD_INCREMENT_USECOUNT;
- AST_LIST_LOCK(&monitors);
- AST_LIST_INSERT_HEAD(&monitors, mixmonitor, list);
- AST_LIST_UNLOCK(&monitors);
-
name = ast_strdupa(mixmonitor->chan->name);
oflags = O_CREAT|O_WRONLY;
@@ -226,7 +218,7 @@ static void *mixmonitor_thread(void *obj)
ast_channel_spy_trigger_wait(&spy);
- if (ast_check_hangup(mixmonitor->chan) || spy.status != CHANSPY_RUNNING || ast_test_flag(mixmonitor, FLAG_STOP)) {
+ if (ast_check_hangup(mixmonitor->chan) || spy.status != CHANSPY_RUNNING) {
ast_mutex_unlock(&spy.lock);
break;
}
@@ -252,8 +244,6 @@ static void *mixmonitor_thread(void *obj)
ast_mutex_unlock(&spy.lock);
}
- stopmon(mixmonitor->chan, &spy);
-
if (mixmonitor->post_process) {
char *p;
@@ -265,6 +255,8 @@ static void *mixmonitor_thread(void *obj)
pbx_substitute_variables_helper(mixmonitor->chan, mixmonitor->post_process, post_process, sizeof(post_process) - 1);
}
+ stopmon(mixmonitor->chan, &spy);
+
if (option_verbose > 1)
ast_verbose(VERBOSE_PREFIX_2 "End MixMonitor Recording %s\n", name);
@@ -281,10 +273,6 @@ out2:
ast_closestream(fs);
out:
- AST_LIST_LOCK(&monitors);
- AST_LIST_REMOVE(&monitors, mixmonitor, list);
- AST_LIST_UNLOCK(&monitors);
-
free(mixmonitor);
STANDARD_DECREMENT_USECOUNT;
@@ -415,7 +403,6 @@ static int mixmonitor_exec(struct ast_channel *chan, void *data)
static int mixmonitor_cli(int fd, int argc, char **argv)
{
struct ast_channel *chan;
- struct mixmonitor *mon;
if (argc < 3)
return RESULT_SHOWUSAGE;
@@ -427,13 +414,8 @@ static int mixmonitor_cli(int fd, int argc, char **argv)
if (!strcasecmp(argv[1], "start"))
mixmonitor_exec(chan, argv[3]);
- else if (!strcasecmp(argv[1], "stop")) {
- AST_LIST_TRAVERSE_SAFE_BEGIN(&monitors, mon, list) {
- if (chan == mon->chan)
- ast_set_flag(mon, FLAG_STOP);
- }
- AST_LIST_TRAVERSE_SAFE_END;
- }
+ else if (!strcasecmp(argv[1], "stop"))
+ ast_channel_spy_stop_by_type(chan, mixmonitor_spy_type);
ast_mutex_unlock(&chan->lock);
@@ -123,9 +119,9 @@ AST_APP_OPTIONS(mixmonitor_opts, {
static void stopmon(struct ast_channel *chan, struct ast_channel_spy *spy)
{
- /* If our status has changed, then the channel we're spying on is gone....
+ /* If our status has changed to DONE, then the channel we're spying on is gone....
DON'T TOUCH IT!!! RUN AWAY!!! */